#

##

##

    	treasure

    	description

    		import vegan.shows_v2.treasure.nature.land

    	structure

    		{
    			"emblem": "",

    			"affiliate": {
    				"links": []
    			},

    			"goodness certifications info": [],

    			"USDA_food": {},
    			"NIH_supp": {},

    			#
    			#	This is the parsed version of
    			#	the USDA_food or NIH_supp
    			#
    			"nature": ../nature/nature.r.HTML
    		}